<?php

namespace Annie\Acts\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Annie\Acts\Http\Requests\ActivityAreaRequest;
use Annie\Acts\Models\ActivityArea;

/**
 * Admin web controller class.
 */
class ActivityAreaWorkflowController extends BaseController
{

    /**
     * Workflow controller function for activity_area.
     *
     * @param Model   $activity_area
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ActivityAreaRequest $request, ActivityArea $activity_area, $step)
    {

        try {

            $activity_area->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('acts::activity_area.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/activity_area/activity_area/' . $activity_area->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/activity_area/activity_area/' . $activity_area->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for activity_area.
     *
     * @param Model   $activity_area
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(ActivityArea $activity_area, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $activity_area->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('acts::activity_area.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('acts::admin.activity_area.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('acts::admin.activity_area.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('acts::admin.activity_area.message', $data)->render();

        }

    }
}
