<?php

namespace Annie\Act\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Annie\Act\Http\Requests\ActivityCollegeRequest;
use Annie\Act\Interfaces\ActivityCollegeRepositoryInterface;
use Annie\Act\Models\ActivityCollege;

/**
 * Resource controller class for activity_college.
 */
class ActivityCollegeResourceController extends BaseController
{

    /**
     * Initialize activity_college resource controller.
     *
     * @param type ActivityCollegeRepositoryInterface $activity_college
     *
     * @return null
     */
    public function __construct(ActivityCollegeRepositoryInterface $activity_college)
    {
        parent::__construct();
        $this->repository = $activity_college;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Annie\Act\Repositories\Criteria\ActivityCollegeResourceCriteria::class);
    }

    /**
     * Display a list of activity_college.
     *
     * @return Response
     */
    public function index(ActivityCollegeRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Annie\Act\Repositories\Presenter\ActivityCollegePresenter::class)
                ->$function();
        }

        $activity_colleges = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('act::activity_college.names'))
            ->view('act::activity_college.index', true)
            ->data(compact('activity_colleges', 'view'))
            ->output();
    }

    /**
     * Display activity_college.
     *
     * @param Request $request
     * @param Model   $activity_college
     *
     * @return Response
     */
    public function show(ActivityCollegeRequest $request, ActivityCollege $activity_college)
    {

        if ($activity_college->exists) {
            $view = 'act::activity_college.show';
        } else {
            $view = 'act::activity_college.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('act::activity_college.name'))
            ->data(compact('activity_college'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new activity_college.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ActivityCollegeRequest $request)
    {

        $activity_college = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('act::activity_college.name')) 
            ->view('act::activity_college.create', true) 
            ->data(compact('activity_college'))
            ->output();
    }

    /**
     * Create new activity_college.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ActivityCollegeRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $activity_college                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('act::activity_college.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('act/activity_college/' . $activity_college->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/act/activity_college'))
                ->redirect();
        }

    }

    /**
     * Show activity_college for editing.
     *
     * @param Request $request
     * @param Model   $activity_college
     *
     * @return Response
     */
    public function edit(ActivityCollegeRequest $request, ActivityCollege $activity_college)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('act::activity_college.name'))
            ->view('act::activity_college.edit', true)
            ->data(compact('activity_college'))
            ->output();
    }

    /**
     * Update the activity_college.
     *
     * @param Request $request
     * @param Model   $activity_college
     *
     * @return Response
     */
    public function update(ActivityCollegeRequest $request, ActivityCollege $activity_college)
    {
        try {
            $attributes = $request->all();

            $activity_college->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('act::activity_college.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('act/activity_college/' . $activity_college->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('act/activity_college/' . $activity_college->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the activity_college.
     *
     * @param Model   $activity_college
     *
     * @return Response
     */
    public function destroy(ActivityCollegeRequest $request, ActivityCollege $activity_college)
    {
        try {

            $activity_college->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('act::activity_college.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('act/activity_college/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('act/activity_college/' . $activity_college->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple activity_college.
     *
     * @param Model   $activity_college
     *
     * @return Response
     */
    public function delete(ActivityCollegeRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('act::activity_college.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('act/activity_college'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/act/activity_college'))
                ->redirect();
        }

    }

    /**
     * Restore deleted activity_colleges.
     *
     * @param Model   $activity_college
     *
     * @return Response
     */
    public function restore(ActivityCollegeRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('act::activity_college.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/act/activity_college'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/act/activity_college/'))
                ->redirect();
        }

    }

}
