<?php

namespace Annie\Act\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Annie\Act\Http\Requests\ActivityCommunityRequest;
use Annie\Act\Models\ActivityCommunity;

/**
 * Admin web controller class.
 */
class ActivityCommunityWorkflowController extends BaseController
{

    /**
     * Workflow controller function for activity_community.
     *
     * @param Model   $activity_community
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ActivityCommunityRequest $request, ActivityCommunity $activity_community, $step)
    {

        try {

            $activity_community->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('act::activity_community.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/activity_community/activity_community/' . $activity_community->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/activity_community/activity_community/' . $activity_community->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for activity_community.
     *
     * @param Model   $activity_community
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(ActivityCommunity $activity_community, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $activity_community->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('act::activity_community.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('act::admin.activity_community.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('act::admin.activity_community.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('act::admin.activity_community.message', $data)->render();

        }

    }
}
