<?php

namespace Annie\Act\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Annie\Act\Http\Requests\ActivityMetumRequest;
use Annie\Act\Interfaces\ActivityMetumRepositoryInterface;
use Annie\Act\Models\ActivityMetum;

/**
 * Resource controller class for activity_metum.
 */
class ActivityMetumResourceController extends BaseController
{

    /**
     * Initialize activity_metum resource controller.
     *
     * @param type ActivityMetumRepositoryInterface $activity_metum
     *
     * @return null
     */
    public function __construct(ActivityMetumRepositoryInterface $activity_metum)
    {
        parent::__construct();
        $this->repository = $activity_metum;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Annie\Act\Repositories\Criteria\ActivityMetumResourceCriteria::class);
    }

    /**
     * Display a list of activity_metum.
     *
     * @return Response
     */
    public function index(ActivityMetumRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Annie\Act\Repositories\Presenter\ActivityMetumPresenter::class)
                ->$function();
        }

        $activity_meta = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('act::activity_metum.names'))
            ->view('act::activity_metum.index', true)
            ->data(compact('activity_meta', 'view'))
            ->output();
    }

    /**
     * Display activity_metum.
     *
     * @param Request $request
     * @param Model   $activity_metum
     *
     * @return Response
     */
    public function show(ActivityMetumRequest $request, ActivityMetum $activity_metum)
    {

        if ($activity_metum->exists) {
            $view = 'act::activity_metum.show';
        } else {
            $view = 'act::activity_metum.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('act::activity_metum.name'))
            ->data(compact('activity_metum'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new activity_metum.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ActivityMetumRequest $request)
    {

        $activity_metum = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('act::activity_metum.name')) 
            ->view('act::activity_metum.create', true) 
            ->data(compact('activity_metum'))
            ->output();
    }

    /**
     * Create new activity_metum.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ActivityMetumRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $activity_metum                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('act::activity_metum.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('act/activity_metum/' . $activity_metum->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/act/activity_metum'))
                ->redirect();
        }

    }

    /**
     * Show activity_metum for editing.
     *
     * @param Request $request
     * @param Model   $activity_metum
     *
     * @return Response
     */
    public function edit(ActivityMetumRequest $request, ActivityMetum $activity_metum)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('act::activity_metum.name'))
            ->view('act::activity_metum.edit', true)
            ->data(compact('activity_metum'))
            ->output();
    }

    /**
     * Update the activity_metum.
     *
     * @param Request $request
     * @param Model   $activity_metum
     *
     * @return Response
     */
    public function update(ActivityMetumRequest $request, ActivityMetum $activity_metum)
    {
        try {
            $attributes = $request->all();

            $activity_metum->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('act::activity_metum.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('act/activity_metum/' . $activity_metum->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('act/activity_metum/' . $activity_metum->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the activity_metum.
     *
     * @param Model   $activity_metum
     *
     * @return Response
     */
    public function destroy(ActivityMetumRequest $request, ActivityMetum $activity_metum)
    {
        try {

            $activity_metum->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('act::activity_metum.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('act/activity_metum/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('act/activity_metum/' . $activity_metum->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple activity_metum.
     *
     * @param Model   $activity_metum
     *
     * @return Response
     */
    public function delete(ActivityMetumRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('act::activity_metum.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('act/activity_metum'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/act/activity_metum'))
                ->redirect();
        }

    }

    /**
     * Restore deleted activity_meta.
     *
     * @param Model   $activity_metum
     *
     * @return Response
     */
    public function restore(ActivityMetumRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('act::activity_metum.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/act/activity_metum'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/act/activity_metum/'))
                ->redirect();
        }

    }

}
