<?php

namespace Annie\Act\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Annie\Act\Http\Requests\ActivityMetumRequest;
use Annie\Act\Models\ActivityMetum;

/**
 * Admin web controller class.
 */
class ActivityMetumWorkflowController extends BaseController
{

    /**
     * Workflow controller function for activity_metum.
     *
     * @param Model   $activity_metum
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ActivityMetumRequest $request, ActivityMetum $activity_metum, $step)
    {

        try {

            $activity_metum->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('act::activity_metum.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/activity_metum/activity_metum/' . $activity_metum->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/activity_metum/activity_metum/' . $activity_metum->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for activity_metum.
     *
     * @param Model   $activity_metum
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(ActivityMetum $activity_metum, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $activity_metum->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('act::activity_metum.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('act::admin.activity_metum.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('act::admin.activity_metum.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('act::admin.activity_metum.message', $data)->render();

        }

    }
}
