<?php

namespace Annie\Act\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Annie\Act\Http\Requests\ActivityProgrammeRequest;
use Annie\Act\Models\ActivityProgramme;

/**
 * Admin web controller class.
 */
class ActivityProgrammeWorkflowController extends BaseController
{

    /**
     * Workflow controller function for activity_programme.
     *
     * @param Model   $activity_programme
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ActivityProgrammeRequest $request, ActivityProgramme $activity_programme, $step)
    {

        try {

            $activity_programme->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('act::activity_programme.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/activity_programme/activity_programme/' . $activity_programme->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/activity_programme/activity_programme/' . $activity_programme->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for activity_programme.
     *
     * @param Model   $activity_programme
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(ActivityProgramme $activity_programme, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $activity_programme->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('act::activity_programme.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('act::admin.activity_programme.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('act::admin.activity_programme.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('act::admin.activity_programme.message', $data)->render();

        }

    }
}
