<?php

namespace Annie\Acts\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Acts\Models\ActivityCollege;

class ActivityCollegePolicy
{

    /**
     * Determine if the given user can view the activity_college.
     *
     * @param UserPolicy $user
     * @param ActivityCollege $activity_college
     *
     * @return bool
     */
    public function view(UserPolicy $user, ActivityCollege $activity_college)
    {
        if ($user->canDo('acts.activity_college.view') && $user->isAdmin()) {
            return true;
        }

        return $activity_college->user_id == user_id() && $activity_college->user_type == user_type();
    }

    /**
     * Determine if the given user can create a activity_college.
     *
     * @param UserPolicy $user
     * @param ActivityCollege $activity_college
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('acts.activity_college.create');
    }

    /**
     * Determine if the given user can update the given activity_college.
     *
     * @param UserPolicy $user
     * @param ActivityCollege $activity_college
     *
     * @return bool
     */
    public function update(UserPolicy $user, ActivityCollege $activity_college)
    {
        if ($user->canDo('acts.activity_college.edit') && $user->isAdmin()) {
            return true;
        }

        return $activity_college->user_id == user_id() && $activity_college->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given activity_college.
     *
     * @param UserPolicy $user
     * @param ActivityCollege $activity_college
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ActivityCollege $activity_college)
    {
        return $activity_college->user_id == user_id() && $activity_college->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given activity_college.
     *
     * @param UserPolicy $user
     * @param ActivityCollege $activity_college
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ActivityCollege $activity_college)
    {
        if ($user->canDo('acts.activity_college.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given activity_college.
     *
     * @param UserPolicy $user
     * @param ActivityCollege $activity_college
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ActivityCollege $activity_college)
    {
        if ($user->canDo('acts.activity_college.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
