<?php

namespace Annie\Acts\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Acts\Models\ActivityLog;

class ActivityLogPolicy
{

    /**
     * Determine if the given user can view the activity_log.
     *
     * @param UserPolicy $user
     * @param ActivityLog $activity_log
     *
     * @return bool
     */
    public function view(UserPolicy $user, ActivityLog $activity_log)
    {
        if ($user->canDo('acts.activity_log.view') && $user->isAdmin()) {
            return true;
        }

        return $activity_log->user_id == user_id() && $activity_log->user_type == user_type();
    }

    /**
     * Determine if the given user can create a activity_log.
     *
     * @param UserPolicy $user
     * @param ActivityLog $activity_log
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('acts.activity_log.create');
    }

    /**
     * Determine if the given user can update the given activity_log.
     *
     * @param UserPolicy $user
     * @param ActivityLog $activity_log
     *
     * @return bool
     */
    public function update(UserPolicy $user, ActivityLog $activity_log)
    {
        if ($user->canDo('acts.activity_log.edit') && $user->isAdmin()) {
            return true;
        }

        return $activity_log->user_id == user_id() && $activity_log->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given activity_log.
     *
     * @param UserPolicy $user
     * @param ActivityLog $activity_log
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ActivityLog $activity_log)
    {
        return $activity_log->user_id == user_id() && $activity_log->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given activity_log.
     *
     * @param UserPolicy $user
     * @param ActivityLog $activity_log
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ActivityLog $activity_log)
    {
        if ($user->canDo('acts.activity_log.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given activity_log.
     *
     * @param UserPolicy $user
     * @param ActivityLog $activity_log
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ActivityLog $activity_log)
    {
        if ($user->canDo('acts.activity_log.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
