<?php

namespace Annie\Act\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Act\Models\ActivityManager;

class ActivityManagerPolicy
{

    /**
     * Determine if the given user can view the activity_manager.
     *
     * @param UserPolicy $user
     * @param ActivityManager $activity_manager
     *
     * @return bool
     */
    public function view(UserPolicy $user, ActivityManager $activity_manager)
    {
        if ($user->canDo('act.activity_manager.view') && $user->isAdmin()) {
            return true;
        }

        return $activity_manager->user_id == user_id() && $activity_manager->user_type == user_type();
    }

    /**
     * Determine if the given user can create a activity_manager.
     *
     * @param UserPolicy $user
     * @param ActivityManager $activity_manager
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('act.activity_manager.create');
    }

    /**
     * Determine if the given user can update the given activity_manager.
     *
     * @param UserPolicy $user
     * @param ActivityManager $activity_manager
     *
     * @return bool
     */
    public function update(UserPolicy $user, ActivityManager $activity_manager)
    {
        if ($user->canDo('act.activity_manager.edit') && $user->isAdmin()) {
            return true;
        }

        return $activity_manager->user_id == user_id() && $activity_manager->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given activity_manager.
     *
     * @param UserPolicy $user
     * @param ActivityManager $activity_manager
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ActivityManager $activity_manager)
    {
        return $activity_manager->user_id == user_id() && $activity_manager->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given activity_manager.
     *
     * @param UserPolicy $user
     * @param ActivityManager $activity_manager
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ActivityManager $activity_manager)
    {
        if ($user->canDo('act.activity_manager.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given activity_manager.
     *
     * @param UserPolicy $user
     * @param ActivityManager $activity_manager
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ActivityManager $activity_manager)
    {
        if ($user->canDo('act.activity_manager.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
