<?php

namespace Annie\Act\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Act\Models\ActivityMetum;

class ActivityMetumPolicy
{

    /**
     * Determine if the given user can view the activity_metum.
     *
     * @param UserPolicy $user
     * @param ActivityMetum $activity_metum
     *
     * @return bool
     */
    public function view(UserPolicy $user, ActivityMetum $activity_metum)
    {
        if ($user->canDo('act.activity_metum.view') && $user->isAdmin()) {
            return true;
        }

        return $activity_metum->user_id == user_id() && $activity_metum->user_type == user_type();
    }

    /**
     * Determine if the given user can create a activity_metum.
     *
     * @param UserPolicy $user
     * @param ActivityMetum $activity_metum
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('act.activity_metum.create');
    }

    /**
     * Determine if the given user can update the given activity_metum.
     *
     * @param UserPolicy $user
     * @param ActivityMetum $activity_metum
     *
     * @return bool
     */
    public function update(UserPolicy $user, ActivityMetum $activity_metum)
    {
        if ($user->canDo('act.activity_metum.edit') && $user->isAdmin()) {
            return true;
        }

        return $activity_metum->user_id == user_id() && $activity_metum->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given activity_metum.
     *
     * @param UserPolicy $user
     * @param ActivityMetum $activity_metum
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ActivityMetum $activity_metum)
    {
        return $activity_metum->user_id == user_id() && $activity_metum->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given activity_metum.
     *
     * @param UserPolicy $user
     * @param ActivityMetum $activity_metum
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ActivityMetum $activity_metum)
    {
        if ($user->canDo('act.activity_metum.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given activity_metum.
     *
     * @param UserPolicy $user
     * @param ActivityMetum $activity_metum
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ActivityMetum $activity_metum)
    {
        if ($user->canDo('act.activity_metum.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
