<?php

namespace Annie\Act\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Annie\Act\Models\ActivityActivityArea;

class ActivityActivityAreaAction
{
    /**
     * Perform the complete action.
     *
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return ActivityActivityArea
     */
    public function complete(ActivityActivityArea $activity_activity_area)
    {
        try {
            $activity_activity_area->status = 'complete';
            return $activity_activity_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return ActivityActivityArea
     */public function verify(ActivityActivityArea $activity_activity_area)
    {
        try {
            $activity_activity_area->status = 'verify';
            return $activity_activity_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return ActivityActivityArea
     */public function approve(ActivityActivityArea $activity_activity_area)
    {
        try {
            $activity_activity_area->status = 'approve';
            return $activity_activity_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return ActivityActivityArea
     */public function publish(ActivityActivityArea $activity_activity_area)
    {
        try {
            $activity_activity_area->status = 'publish';
            return $activity_activity_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return ActivityActivityArea
     */
    public function archive(ActivityActivityArea $activity_activity_area)
    {
        try {
            $activity_activity_area->status = 'archive';
            return $activity_activity_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return ActivityActivityArea
     */
    public function unpublish(ActivityActivityArea $activity_activity_area)
    {
        try {
            $activity_activity_area->status = 'unpublish';
            return $activity_activity_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
