<?php

namespace Annie\Act\Workflow;

use Annie\Act\Models\ActivityActivityArea;
use Validator;

class ActivityActivityAreaValidator
{

    /**
     * Determine if the given activity_activity_area is valid for complete status.
     *
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return bool / Validator
     */
    public function complete(ActivityActivityArea $activity_activity_area)
    {
        return Validator::make($activity_activity_area->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given activity_activity_area is valid for verify status.
     *
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return bool / Validator
     */
    public function verify(ActivityActivityArea $activity_activity_area)
    {
        return Validator::make($activity_activity_area->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given activity_activity_area is valid for approve status.
     *
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return bool / Validator
     */
    public function approve(ActivityActivityArea $activity_activity_area)
    {
        return Validator::make($activity_activity_area->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given activity_activity_area is valid for publish status.
     *
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return bool / Validator
     */
    public function publish(ActivityActivityArea $activity_activity_area)
    {
        return Validator::make($activity_activity_area->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given activity_activity_area is valid for archive status.
     *
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return bool / Validator
     */
    public function archive(ActivityActivityArea $activity_activity_area)
    {
        return Validator::make($activity_activity_area->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given activity_activity_area is valid for unpublish status.
     *
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return bool / Validator
     */
    public function unpublish(ActivityActivityArea $activity_activity_area)
    {
        return Validator::make($activity_activity_area->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
