<?php

namespace Annie\Act\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Annie\Act\Models\ActivityArea;

class ActivityAreaAction
{
    /**
     * Perform the complete action.
     *
     * @param ActivityArea $activity_area
     *
     * @return ActivityArea
     */
    public function complete(ActivityArea $activity_area)
    {
        try {
            $activity_area->status = 'complete';
            return $activity_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param ActivityArea $activity_area
     *
     * @return ActivityArea
     */public function verify(ActivityArea $activity_area)
    {
        try {
            $activity_area->status = 'verify';
            return $activity_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param ActivityArea $activity_area
     *
     * @return ActivityArea
     */public function approve(ActivityArea $activity_area)
    {
        try {
            $activity_area->status = 'approve';
            return $activity_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param ActivityArea $activity_area
     *
     * @return ActivityArea
     */public function publish(ActivityArea $activity_area)
    {
        try {
            $activity_area->status = 'publish';
            return $activity_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param ActivityArea $activity_area
     *
     * @return ActivityArea
     */
    public function archive(ActivityArea $activity_area)
    {
        try {
            $activity_area->status = 'archive';
            return $activity_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param ActivityArea $activity_area
     *
     * @return ActivityArea
     */
    public function unpublish(ActivityArea $activity_area)
    {
        try {
            $activity_area->status = 'unpublish';
            return $activity_area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
