<?php

namespace Annie\Acts\Workflow;

use Annie\Acts\Models\ActivityCollege;
use Validator;

class ActivityCollegeValidator
{

    /**
     * Determine if the given activity_college is valid for complete status.
     *
     * @param ActivityCollege $activity_college
     *
     * @return bool / Validator
     */
    public function complete(ActivityCollege $activity_college)
    {
        return Validator::make($activity_college->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given activity_college is valid for verify status.
     *
     * @param ActivityCollege $activity_college
     *
     * @return bool / Validator
     */
    public function verify(ActivityCollege $activity_college)
    {
        return Validator::make($activity_college->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given activity_college is valid for approve status.
     *
     * @param ActivityCollege $activity_college
     *
     * @return bool / Validator
     */
    public function approve(ActivityCollege $activity_college)
    {
        return Validator::make($activity_college->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given activity_college is valid for publish status.
     *
     * @param ActivityCollege $activity_college
     *
     * @return bool / Validator
     */
    public function publish(ActivityCollege $activity_college)
    {
        return Validator::make($activity_college->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given activity_college is valid for archive status.
     *
     * @param ActivityCollege $activity_college
     *
     * @return bool / Validator
     */
    public function archive(ActivityCollege $activity_college)
    {
        return Validator::make($activity_college->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given activity_college is valid for unpublish status.
     *
     * @param ActivityCollege $activity_college
     *
     * @return bool / Validator
     */
    public function unpublish(ActivityCollege $activity_college)
    {
        return Validator::make($activity_college->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
