<?php

namespace Annie\Act\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Annie\Act\Models\ActivityCommunity;

class ActivityCommunityAction
{
    /**
     * Perform the complete action.
     *
     * @param ActivityCommunity $activity_community
     *
     * @return ActivityCommunity
     */
    public function complete(ActivityCommunity $activity_community)
    {
        try {
            $activity_community->status = 'complete';
            return $activity_community->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param ActivityCommunity $activity_community
     *
     * @return ActivityCommunity
     */public function verify(ActivityCommunity $activity_community)
    {
        try {
            $activity_community->status = 'verify';
            return $activity_community->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param ActivityCommunity $activity_community
     *
     * @return ActivityCommunity
     */public function approve(ActivityCommunity $activity_community)
    {
        try {
            $activity_community->status = 'approve';
            return $activity_community->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param ActivityCommunity $activity_community
     *
     * @return ActivityCommunity
     */public function publish(ActivityCommunity $activity_community)
    {
        try {
            $activity_community->status = 'publish';
            return $activity_community->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param ActivityCommunity $activity_community
     *
     * @return ActivityCommunity
     */
    public function archive(ActivityCommunity $activity_community)
    {
        try {
            $activity_community->status = 'archive';
            return $activity_community->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param ActivityCommunity $activity_community
     *
     * @return ActivityCommunity
     */
    public function unpublish(ActivityCommunity $activity_community)
    {
        try {
            $activity_community->status = 'unpublish';
            return $activity_community->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
