<?php

namespace Annie\Acts\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Annie\Acts\Models\ActivityManager;

class ActivityManagerAction
{
    /**
     * Perform the complete action.
     *
     * @param ActivityManager $activity_manager
     *
     * @return ActivityManager
     */
    public function complete(ActivityManager $activity_manager)
    {
        try {
            $activity_manager->status = 'complete';
            return $activity_manager->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param ActivityManager $activity_manager
     *
     * @return ActivityManager
     */public function verify(ActivityManager $activity_manager)
    {
        try {
            $activity_manager->status = 'verify';
            return $activity_manager->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param ActivityManager $activity_manager
     *
     * @return ActivityManager
     */public function approve(ActivityManager $activity_manager)
    {
        try {
            $activity_manager->status = 'approve';
            return $activity_manager->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param ActivityManager $activity_manager
     *
     * @return ActivityManager
     */public function publish(ActivityManager $activity_manager)
    {
        try {
            $activity_manager->status = 'publish';
            return $activity_manager->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param ActivityManager $activity_manager
     *
     * @return ActivityManager
     */
    public function archive(ActivityManager $activity_manager)
    {
        try {
            $activity_manager->status = 'archive';
            return $activity_manager->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param ActivityManager $activity_manager
     *
     * @return ActivityManager
     */
    public function unpublish(ActivityManager $activity_manager)
    {
        try {
            $activity_manager->status = 'unpublish';
            return $activity_manager->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
