<?php

namespace Annie\Acts\Workflow;

use Annie\Acts\Models\ActivityManager;
use Validator;

class ActivityManagerValidator
{

    /**
     * Determine if the given activity_manager is valid for complete status.
     *
     * @param ActivityManager $activity_manager
     *
     * @return bool / Validator
     */
    public function complete(ActivityManager $activity_manager)
    {
        return Validator::make($activity_manager->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given activity_manager is valid for verify status.
     *
     * @param ActivityManager $activity_manager
     *
     * @return bool / Validator
     */
    public function verify(ActivityManager $activity_manager)
    {
        return Validator::make($activity_manager->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given activity_manager is valid for approve status.
     *
     * @param ActivityManager $activity_manager
     *
     * @return bool / Validator
     */
    public function approve(ActivityManager $activity_manager)
    {
        return Validator::make($activity_manager->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given activity_manager is valid for publish status.
     *
     * @param ActivityManager $activity_manager
     *
     * @return bool / Validator
     */
    public function publish(ActivityManager $activity_manager)
    {
        return Validator::make($activity_manager->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given activity_manager is valid for archive status.
     *
     * @param ActivityManager $activity_manager
     *
     * @return bool / Validator
     */
    public function archive(ActivityManager $activity_manager)
    {
        return Validator::make($activity_manager->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given activity_manager is valid for unpublish status.
     *
     * @param ActivityManager $activity_manager
     *
     * @return bool / Validator
     */
    public function unpublish(ActivityManager $activity_manager)
    {
        return Validator::make($activity_manager->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
