<?php

namespace Annie\Acts\Workflow;

use Annie\Acts\Models\ActivityMetum;
use Validator;

class ActivityMetumValidator
{

    /**
     * Determine if the given activity_metum is valid for complete status.
     *
     * @param ActivityMetum $activity_metum
     *
     * @return bool / Validator
     */
    public function complete(ActivityMetum $activity_metum)
    {
        return Validator::make($activity_metum->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given activity_metum is valid for verify status.
     *
     * @param ActivityMetum $activity_metum
     *
     * @return bool / Validator
     */
    public function verify(ActivityMetum $activity_metum)
    {
        return Validator::make($activity_metum->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given activity_metum is valid for approve status.
     *
     * @param ActivityMetum $activity_metum
     *
     * @return bool / Validator
     */
    public function approve(ActivityMetum $activity_metum)
    {
        return Validator::make($activity_metum->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given activity_metum is valid for publish status.
     *
     * @param ActivityMetum $activity_metum
     *
     * @return bool / Validator
     */
    public function publish(ActivityMetum $activity_metum)
    {
        return Validator::make($activity_metum->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given activity_metum is valid for archive status.
     *
     * @param ActivityMetum $activity_metum
     *
     * @return bool / Validator
     */
    public function archive(ActivityMetum $activity_metum)
    {
        return Validator::make($activity_metum->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given activity_metum is valid for unpublish status.
     *
     * @param ActivityMetum $activity_metum
     *
     * @return bool / Validator
     */
    public function unpublish(ActivityMetum $activity_metum)
    {
        return Validator::make($activity_metum->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
