<?php

namespace Annie\Act\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Annie\Act\Models\ActivityProgramme;

class ActivityProgrammeAction
{
    /**
     * Perform the complete action.
     *
     * @param ActivityProgramme $activity_programme
     *
     * @return ActivityProgramme
     */
    public function complete(ActivityProgramme $activity_programme)
    {
        try {
            $activity_programme->status = 'complete';
            return $activity_programme->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param ActivityProgramme $activity_programme
     *
     * @return ActivityProgramme
     */public function verify(ActivityProgramme $activity_programme)
    {
        try {
            $activity_programme->status = 'verify';
            return $activity_programme->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param ActivityProgramme $activity_programme
     *
     * @return ActivityProgramme
     */public function approve(ActivityProgramme $activity_programme)
    {
        try {
            $activity_programme->status = 'approve';
            return $activity_programme->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param ActivityProgramme $activity_programme
     *
     * @return ActivityProgramme
     */public function publish(ActivityProgramme $activity_programme)
    {
        try {
            $activity_programme->status = 'publish';
            return $activity_programme->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param ActivityProgramme $activity_programme
     *
     * @return ActivityProgramme
     */
    public function archive(ActivityProgramme $activity_programme)
    {
        try {
            $activity_programme->status = 'archive';
            return $activity_programme->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param ActivityProgramme $activity_programme
     *
     * @return ActivityProgramme
     */
    public function unpublish(ActivityProgramme $activity_programme)
    {
        try {
            $activity_programme->status = 'unpublish';
            return $activity_programme->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
