<?php

namespace Annie\Acts\Workflow;

use Annie\Acts\Models\ActivityProgramme;
use Validator;

class ActivityProgrammeValidator
{

    /**
     * Determine if the given activity_programme is valid for complete status.
     *
     * @param ActivityProgramme $activity_programme
     *
     * @return bool / Validator
     */
    public function complete(ActivityProgramme $activity_programme)
    {
        return Validator::make($activity_programme->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given activity_programme is valid for verify status.
     *
     * @param ActivityProgramme $activity_programme
     *
     * @return bool / Validator
     */
    public function verify(ActivityProgramme $activity_programme)
    {
        return Validator::make($activity_programme->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given activity_programme is valid for approve status.
     *
     * @param ActivityProgramme $activity_programme
     *
     * @return bool / Validator
     */
    public function approve(ActivityProgramme $activity_programme)
    {
        return Validator::make($activity_programme->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given activity_programme is valid for publish status.
     *
     * @param ActivityProgramme $activity_programme
     *
     * @return bool / Validator
     */
    public function publish(ActivityProgramme $activity_programme)
    {
        return Validator::make($activity_programme->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given activity_programme is valid for archive status.
     *
     * @param ActivityProgramme $activity_programme
     *
     * @return bool / Validator
     */
    public function archive(ActivityProgramme $activity_programme)
    {
        return Validator::make($activity_programme->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given activity_programme is valid for unpublish status.
     *
     * @param ActivityProgramme $activity_programme
     *
     * @return bool / Validator
     */
    public function unpublish(ActivityProgramme $activity_programme)
    {
        return Validator::make($activity_programme->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
