<?php

namespace Annie\Act\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Annie\Act\Models\ActivityProject;

class ActivityProjectAction
{
    /**
     * Perform the complete action.
     *
     * @param ActivityProject $activity_project
     *
     * @return ActivityProject
     */
    public function complete(ActivityProject $activity_project)
    {
        try {
            $activity_project->status = 'complete';
            return $activity_project->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param ActivityProject $activity_project
     *
     * @return ActivityProject
     */public function verify(ActivityProject $activity_project)
    {
        try {
            $activity_project->status = 'verify';
            return $activity_project->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param ActivityProject $activity_project
     *
     * @return ActivityProject
     */public function approve(ActivityProject $activity_project)
    {
        try {
            $activity_project->status = 'approve';
            return $activity_project->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param ActivityProject $activity_project
     *
     * @return ActivityProject
     */public function publish(ActivityProject $activity_project)
    {
        try {
            $activity_project->status = 'publish';
            return $activity_project->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param ActivityProject $activity_project
     *
     * @return ActivityProject
     */
    public function archive(ActivityProject $activity_project)
    {
        try {
            $activity_project->status = 'archive';
            return $activity_project->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param ActivityProject $activity_project
     *
     * @return ActivityProject
     */
    public function unpublish(ActivityProject $activity_project)
    {
        try {
            $activity_project->status = 'unpublish';
            return $activity_project->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
