<?php

namespace Annie\Acts\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Annie\Acts\Models\ActivitySchool;

class ActivitySchoolAction
{
    /**
     * Perform the complete action.
     *
     * @param ActivitySchool $activity_school
     *
     * @return ActivitySchool
     */
    public function complete(ActivitySchool $activity_school)
    {
        try {
            $activity_school->status = 'complete';
            return $activity_school->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param ActivitySchool $activity_school
     *
     * @return ActivitySchool
     */public function verify(ActivitySchool $activity_school)
    {
        try {
            $activity_school->status = 'verify';
            return $activity_school->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param ActivitySchool $activity_school
     *
     * @return ActivitySchool
     */public function approve(ActivitySchool $activity_school)
    {
        try {
            $activity_school->status = 'approve';
            return $activity_school->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param ActivitySchool $activity_school
     *
     * @return ActivitySchool
     */public function publish(ActivitySchool $activity_school)
    {
        try {
            $activity_school->status = 'publish';
            return $activity_school->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param ActivitySchool $activity_school
     *
     * @return ActivitySchool
     */
    public function archive(ActivitySchool $activity_school)
    {
        try {
            $activity_school->status = 'archive';
            return $activity_school->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param ActivitySchool $activity_school
     *
     * @return ActivitySchool
     */
    public function unpublish(ActivitySchool $activity_school)
    {
        try {
            $activity_school->status = 'unpublish';
            return $activity_school->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
