<?php

namespace Annie\Acts\Workflow;

use Annie\Acts\Models\ActivitySchool;
use Validator;

class ActivitySchoolValidator
{

    /**
     * Determine if the given activity_school is valid for complete status.
     *
     * @param ActivitySchool $activity_school
     *
     * @return bool / Validator
     */
    public function complete(ActivitySchool $activity_school)
    {
        return Validator::make($activity_school->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given activity_school is valid for verify status.
     *
     * @param ActivitySchool $activity_school
     *
     * @return bool / Validator
     */
    public function verify(ActivitySchool $activity_school)
    {
        return Validator::make($activity_school->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given activity_school is valid for approve status.
     *
     * @param ActivitySchool $activity_school
     *
     * @return bool / Validator
     */
    public function approve(ActivitySchool $activity_school)
    {
        return Validator::make($activity_school->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given activity_school is valid for publish status.
     *
     * @param ActivitySchool $activity_school
     *
     * @return bool / Validator
     */
    public function publish(ActivitySchool $activity_school)
    {
        return Validator::make($activity_school->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given activity_school is valid for archive status.
     *
     * @param ActivitySchool $activity_school
     *
     * @return bool / Validator
     */
    public function archive(ActivitySchool $activity_school)
    {
        return Validator::make($activity_school->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given activity_school is valid for unpublish status.
     *
     * @param ActivitySchool $activity_school
     *
     * @return bool / Validator
     */
    public function unpublish(ActivitySchool $activity_school)
    {
        return Validator::make($activity_school->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
