<?php

namespace Annie\Act\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Annie\Act\Models\ActivitySocialPartner;

class ActivitySocialPartnerAction
{
    /**
     * Perform the complete action.
     *
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return ActivitySocialPartner
     */
    public function complete(ActivitySocialPartner $activity_social_partner)
    {
        try {
            $activity_social_partner->status = 'complete';
            return $activity_social_partner->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return ActivitySocialPartner
     */public function verify(ActivitySocialPartner $activity_social_partner)
    {
        try {
            $activity_social_partner->status = 'verify';
            return $activity_social_partner->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return ActivitySocialPartner
     */public function approve(ActivitySocialPartner $activity_social_partner)
    {
        try {
            $activity_social_partner->status = 'approve';
            return $activity_social_partner->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return ActivitySocialPartner
     */public function publish(ActivitySocialPartner $activity_social_partner)
    {
        try {
            $activity_social_partner->status = 'publish';
            return $activity_social_partner->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return ActivitySocialPartner
     */
    public function archive(ActivitySocialPartner $activity_social_partner)
    {
        try {
            $activity_social_partner->status = 'archive';
            return $activity_social_partner->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return ActivitySocialPartner
     */
    public function unpublish(ActivitySocialPartner $activity_social_partner)
    {
        try {
            $activity_social_partner->status = 'unpublish';
            return $activity_social_partner->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
