<?php

namespace Annie\Act\Workflow;

use Annie\Act\Models\ActivitySocialPartner;
use Validator;

class ActivitySocialPartnerValidator
{

    /**
     * Determine if the given activity_social_partner is valid for complete status.
     *
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return bool / Validator
     */
    public function complete(ActivitySocialPartner $activity_social_partner)
    {
        return Validator::make($activity_social_partner->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given activity_social_partner is valid for verify status.
     *
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return bool / Validator
     */
    public function verify(ActivitySocialPartner $activity_social_partner)
    {
        return Validator::make($activity_social_partner->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given activity_social_partner is valid for approve status.
     *
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return bool / Validator
     */
    public function approve(ActivitySocialPartner $activity_social_partner)
    {
        return Validator::make($activity_social_partner->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given activity_social_partner is valid for publish status.
     *
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return bool / Validator
     */
    public function publish(ActivitySocialPartner $activity_social_partner)
    {
        return Validator::make($activity_social_partner->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given activity_social_partner is valid for archive status.
     *
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return bool / Validator
     */
    public function archive(ActivitySocialPartner $activity_social_partner)
    {
        return Validator::make($activity_social_partner->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given activity_social_partner is valid for unpublish status.
     *
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return bool / Validator
     */
    public function unpublish(ActivitySocialPartner $activity_social_partner)
    {
        return Validator::make($activity_social_partner->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
